package com.bbc.denadrive.home

import android.media.tv.TvContract.Channels.Logo
import android.util.Log
import androidx.compose.animation.core.animateFloatAsState
import androidx.compose.foundation.background
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.navigation.NavHostController
import androidx.compose.foundation.gestures.detectTapGestures
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Menu
import androidx.compose.material.icons.filled.MoreVert
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.scale
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.input.pointer.pointerInput
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import kotlinx.coroutines.launch
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.ui.graphics.painter.Painter
import androidx.compose.foundation.Image
import androidx.compose.ui.res.painterResource
import com.bbc.denadrive.NavigationGraph
import com.bbc.denadrive.R
import com.bbc.denadrive.apihandlers.ResponsesHandler

@Composable
fun HomeScreen(navController: NavHostController) {
    Button(onClick = { navController.navigate("details/1") }) {
        Text("Go to Details")
    }
}

@Composable
fun DetailsScreen(itemId: String?, navController: NavHostController) {
    Text(text = "Details for item: $itemId")
}


@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun ScaffoldWithSidebar(
    navController: NavHostController,
    responsesHandler: ResponsesHandler,
    doIt: () -> Unit,
//    toBeDisplayed: @Composable () -> Unit
) {
    // State to control the drawer
    val drawerState = rememberDrawerState(initialValue = DrawerValue.Closed)
    val scope = rememberCoroutineScope()

    // ModalNavigationDrawer
    ModalNavigationDrawer(
        drawerState = drawerState,
        drawerContent = {
            // Drawer content
            Column(
                modifier = Modifier
                    .fillMaxHeight()
                    .fillMaxWidth(0.67f)
                    .background(Color.White)
            ) {
                RectangularButton(backgroundColor = Color.White, text = "Text 1") {  }
//                Spacer(modifier = Modifier.height(10.dp))
                RectangularButton(backgroundColor = Color.White, text = "Text 2") {  }
//                Spacer(modifier = Modifier.height(10.dp))
                RectangularButton(backgroundColor = Color.White, text = "Text 3") {  }
            }
        },
        content = {
            // Main content of the screen
            Scaffold(
                topBar = {
                    TopAppBar(
                        title = { Text("My App") },
                        navigationIcon = {
                            IconButton(onClick = {
                                scope.launch {
                                    drawerState.open()
                                }
                            }) {
                                // Icon for the menu (three horizontal lines)
                                Icon(Icons.Filled.Menu, contentDescription = "Menu")
                            }
                        },
                        actions = {
                            IconButton(onClick = { doIt() }) {
                                // Icon for the settings (three vertical dots)
                                Icon(Icons.Filled.MoreVert, contentDescription = "Settings")
                            }
                        }
                    )
                },
                content = { innerPadding ->
                    Box(
                        modifier = Modifier
                            .fillMaxSize()
                            .padding(innerPadding)
                            .padding(16.dp),
                        contentAlignment = Alignment.TopCenter,
                    ) {
                        NavigationGraph(navController, responsesHandler)
//                        toBeDisplayed()
//                        Text("Main Content", fontSize = 24.sp)
                    }
                }
            )
        }
    )
}

@Composable
fun RectangularButton(
    backgroundColor: Color,
    text: String,
    onClick: () -> Unit
) {
    var isPressed by remember { mutableStateOf(false) }
    val scale by animateFloatAsState(if (isPressed) 0.8f else 1f)

    Box(
        modifier = Modifier
            .fillMaxWidth()
            .height(48.dp) // Set the height of the button
            .background(color = backgroundColor) // Set the background color
            .scale(scale) // Apply the scale effect
            .pointerInput(Unit) {
                // Detect press and release gestures
                detectTapGestures(
                    onPress = {
                        isPressed = true
                        // Wait for the click to be released
                        tryAwaitRelease()
                        isPressed = false
                    },
                    onTap = { onClick() } // Call the onClick action
                )
            }
            .padding(8.dp),
        contentAlignment = Alignment.Center // Center the text
    ) {
        Text(text = text, style = MaterialTheme.typography.bodyLarge) // Button text
    }
}

@Composable
fun MyListVisualizer(responsesHandler: ResponsesHandler) {
    Log.e("CHECKING", "MyListVisualizer: REDRAWN", )
    val fileList = mutableListOf<String>()
    if (responsesHandler.lastResponseBody.value == null) {
        fileList.clear()
        fileList.addAll(
            listOf("a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n",
            "o", "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z")
        )
    } else {
        fileList.clear()
        fileList.addAll(
            responsesHandler.lastResponseBody.value!!.toList()
        )
    }
//    val fileList = driveResponseBody.value?.toList()
//        ?: listOf("a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n",
//            "o", "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z")
//    LazyColumn {
//        items(fileList) { name -> Text(text=name, fontSize = 30.sp) }
//    }
    LazyColumn {
        items(fileList) { name ->
            val logo = painterResource(id = R.drawable.vecchiaicona_)
            LogoTextBox(logo, name)
        }
    }
}

@Composable
fun LogoTextBox(logoPainter: Painter, text: String) {
    Card(
        modifier = Modifier
            .fillMaxWidth()
            .padding(16.dp),
        shape = RoundedCornerShape(8.dp),
        elevation = CardDefaults.cardElevation(defaultElevation = 4.dp)
    ) {
        Row(
            modifier = Modifier
                .padding(16.dp)
                .fillMaxWidth(),
            verticalAlignment = Alignment.CenterVertically
        ) {
            // Logo on the left
            Image(
                painter = logoPainter,
                contentDescription = "Logo",
                modifier = Modifier
                    .size(40.dp) // Adjust size as needed
                    .padding(end = 16.dp) // Space between logo and text
            )

            // Text to the right of the logo
            Text(
                text = text,
                fontSize = 20.sp,
                color = Color.Black
            )
        }
    }
}

//@Composable
//fun MyApp() {
//    ScaffoldWithSidebar()
//}

//@Composable
//fun MainActivityContent() {
//    MyApp()
//}


//@OptIn(ExperimentalMaterial3Api::class)
//@Composable
//fun ScaffoldWithSidebar() {
//    // State to control the drawer
//    var isDrawerOpen by remember { mutableStateOf(false) }
//
//    // Main Scaffold
//    Scaffold(
//        topBar = {
//            TopAppBar(
//                title = { Text("My App") },
//                navigationIcon = {
//                    IconButton(onClick = { isDrawerOpen = true }) {
//                        // Icon for the menu (three horizontal lines)
//                        Icon(Icons.Filled.Menu, contentDescription = "Menu")
//                    }
//                },
//                actions = {
//                    IconButton(onClick = { /* Handle settings click */ }) {
//                        // Icon for the settings (three vertical dots)
//                        Icon(Icons.Filled.MoreVert, contentDescription = "Settings")
//                    }
//                }
//            )
//        },
//        drawerContent = {
//            // Drawer content
//            Column(
//                modifier = Modifier
//                    .fillMaxSize()
//                    .padding(16.dp)
//            ) {
//                Text("Item 1", modifier = Modifier.clickable { /* Handle click */ })
//                Spacer(modifier = Modifier.height(8.dp))
//                Text("Item 2", modifier = Modifier.clickable { /* Handle click */ })
//                Spacer(modifier = Modifier.height(8.dp))
//                Text("Item 3", modifier = Modifier.clickable { /* Handle click */ })
//            }
//        },
//        drawerGesturesEnabled = true,
//        drawerShape = MaterialTheme.shapes.large,
//        drawerContentColor = MaterialTheme.colorScheme.background,
//        drawerContainerColor = MaterialTheme.colorScheme.surface,
//        content = { padding ->
//            // Main content of the screen
//            Box(
//                modifier = Modifier
//                    .fillMaxSize()
//                    .padding(padding)
//                    .background(Color.White),
//                contentAlignment = Alignment.Center
//            ) {
//                Text("Main Content", fontSize = 24.sp)
//            }
//        }
//    )
//
//    // Handle drawer state
//    if (isDrawerOpen) {
//        // Close the drawer when clicking outside
//        Box(
//            modifier = Modifier
//                .fillMaxSize()
//                .background(Color.Black.copy(alpha = 0.5f))
//                .clickable { isDrawerOpen = false }
//        )
//    }
//}
